pub struct TimeSyscall { /* private fields */ }Expand description
Syscall handler for providing time information since boot to CKB-VM. While this is not exactly the time for the outside world, it can be used to build benchmarks within CKB-VM.
Implementations
Sourceimpl TimeSyscall
impl TimeSyscall